@@ -4,6 +4,11 @@ int add(int i, int j) {
     return i + j;
 }
 
+int subtract(int i, int j) {
+    return i - j;
+}
+
 PYBIND11_MODULE(python_example_wierdre, m) {
     m.def("add", add, "add function");
+    m.def("subtract", subtract, "subtract function");
 }
\ No newline at end of file
